@@ -13,9 +13,16 @@ use std::f32::consts::FRAC_PI_2;
 use std::mem::size_of;
 
 /// Offset relative to the size of a pixel used by the fragment shader to
-/// implement multi-sampling.
-const OFFSET: f32 = 0.125;
+/// implement 4x multi-sampling. The pattern is defined by the fragment shader.
+const OFFSET: f32 = 0.5 * std::f32::consts::FRAC_1_SQRT_2;
 
+/// Vertex
+///
+/// -   `screen_pos: Vec2` — screen coordinate
+/// -   `colour: Rgba`
+/// -   `dir: Vec2` — normalised direction of slope (from (-1, -1) to (1, 1))
+/// -   `adjust: Vec2`
+/// -   `pix_offset: Vec2` — offset for a pixel; used for AA
 #[repr(C)]
 #[derive(Clone, Copy, Debug)]
 pub struct Vertex(Vec2, Rgba, Vec2, Vec2, Vec2);
@@ -31,6 +38,8 @@ impl Vertex {
 pub type Window = common::Window<Vertex>;
 
 /// A pipeline for rendering rounded shapes
+///
+/// Uses 4x sampling for anti-aliasing.
 pub struct Pipeline {
     render_pipeline: wgpu::RenderPipeline,
 }
@@ -52,11 +61,11 @@ impl Pipeline {
             label: Some("SR render_pipeline"),
             layout: Some(&pipeline_layout),
             vertex: wgpu::VertexState {
-                module: &shaders.vert_222,
+                module: &shaders.vert_shaded_round,
                 entry_point: "main",
                 buffers: &[wgpu::VertexBufferLayout {
                     array_stride: size_of::<Vertex>() as wgpu::BufferAddress,
-                    step_mode: wgpu::InputStepMode::Vertex,
+                    step_mode: wgpu::VertexStepMode::Vertex,
                     attributes: &wgpu::vertex_attr_array![
                         0 => Float32x2,
                         1 => Float32x4,
@@ -83,7 +92,7 @@ impl Pipeline {
                 targets: &[wgpu::ColorTargetState {
                     format: super::RENDER_TEX_FORMAT,
                     blend: Some(wgpu::BlendState::ALPHA_BLENDING),
-                    write_mask: wgpu::ColorWrite::ALL,
+                    write_mask: wgpu::ColorWrites::ALL,
                 }],
             }),
         });
