@@ -61,7 +61,8 @@ where
         info!("Using graphics adapter: {}", adapter.get_info().name);
 
         let desc = CB::device_descriptor();
-        let req = adapter.request_device(&desc, None);
+        let trace_path = options.wgpu_trace_path.as_ref().map(|p| p.as_path());
+        let req = adapter.request_device(&desc, trace_path);
         let device_and_queue = futures::executor::block_on(req)?;
 
         let pipe = DrawPipe::new(custom, device_and_queue, theme.config().raster());
@@ -183,7 +184,10 @@ where
     }
 
     pub fn on_exit(&self) {
-        match self.options.save_config(&self.config.borrow(), &self.theme) {
+        match self
+            .options
+            .write_config(&self.config.borrow(), &self.theme)
+        {
             Ok(()) => (),
             Err(error) => warn_about_error("Failed to save config", &error),
         }
